@@ -1,7 +1,15 @@
 #' ITIS Solr search
 #'
 #' @export
-#' @param ... Args passed to \code{\link[solrium]{solr_search}}
+#' @param ... Arguments passed on to the `params` parameter of
+#' the [solrium::solr_search()] function. See [solr_fields] for possible
+#' parameters, and examples below
+#' @param proxy List of arguments for a proxy connection,
+#' including one or more of: url, port, username, password,
+#' and auth. See [crul::proxy()] for  help, which is used to
+#' construct the proxy connection.
+#' @param callopts Curl options passed on to [crul::HttpClient]
+#' @references <https://www.itis.gov/solr_documentation.html>
 #' @examples \dontrun{
 #' itis_search(q = "tsn:182662")
 #'
@@ -23,7 +31,10 @@
 #' itis_search(q = "nameWOInd:/[A-Za-z0-9]*[%20]{0,0}*/",
 #'    fl = c('nameWInd', 'tsn'))
 #' }
-itis_search <- function(...) {
-  invisible(solrium::solr_connect(url = itis_solr_url()))
-  solrium::solr_search(...)
+itis_search <- function(..., proxy = NULL, callopts=list()) {
+  if (!is.null(proxy)) conn_dc <- make_itis_conn(proxy)
+  args <- list(...)
+	if (!is.null(args$fl)) args$fl <- paste(args$fl, collapse = ",")
+  conn_itis$search(params = args, minOptimizedRows = FALSE,
+  	callopts = callopts)
 }
